CheckBoxProperty class
Configuration class for customizing checkbox appearance and behavior in dropdown widgets.
This class provides comprehensive customization options for checkboxes used in multi-select dropdown widgets, including colors, focus behavior, visual density, and interaction properties.
Constructors
-
CheckBoxProperty({bool tristate = false, MouseCursor? mouseCursor, Color? activeColor, WidgetStateProperty<
Color?> ? fillColor, Color? checkColor, Color? focusColor, Color? hoverColor, WidgetStateProperty<Color?> ? overlayColor, double? splashRadius, MaterialTapTargetSize? materialTapTargetSize, VisualDensity? visualDensity, FocusNode? focusNode, bool autofocus = false, OutlinedBorder? shape, BorderSide? side}) - Creates a CheckBoxProperty with customizable checkbox properties.
Properties
- activeColor → Color?
-
The color to use when this checkbox is checked.
final
- autofocus → bool
-
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
final
- checkColor → Color?
-
The color to use for the check icon when this checkbox is checked.
final
-
fillColor
→ WidgetStateProperty<
Color?> ? -
The color that fills the checkbox, in all WidgetStates.
final
- focusColor → Color?
-
The color for the checkbox's focus indicator.
final
- focusNode → FocusNode?
-
An optional focus node to use as the focus node for this widget.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverColor → Color?
-
The color for the checkbox's hover effect.
final
- materialTapTargetSize → MaterialTapTargetSize?
-
Configures the minimum size of the tap target.
final
- mouseCursor → MouseCursor?
-
The cursor for a mouse pointer when it enters or is hovering over the checkbox.
final
-
overlayColor
→ WidgetStateProperty<
Color?> ? -
The color for the checkbox's overlay, in all WidgetStates.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → OutlinedBorder?
-
The shape of the checkbox's border.
final
- side → BorderSide?
-
The color and width of the checkbox's border.
final
- splashRadius → double?
-
The splash radius of the circular Material ink response.
final
- tristate → bool
-
If true, the checkbox's value can be true, false, or null.
final
- visualDensity → VisualDensity?
-
Defines how compact the checkbox's layout will be.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited